Stan Math Library: stan/math/rev/core/var.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces | Functions
var.hpp File Reference
`#include <stan/math/rev/core/vari.hpp>`
`#include <stan/math/rev/core/grad.hpp>`
`#include <stan/math/rev/core/chainable_alloc.hpp>`
`#include <boost/math/tools/config.hpp>`
`#include <ostream>`
`#include <vector>`

Go to the source code of this file.

## Classes
class | stan::math::var
| Independent (input) and dependent (output) variables for gradients. More...

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
static void | stan::math::grad (vari *vi)

[ Stan Home Page ] © 2011–2016, Stan Development Team.